<?php

namespace Celebs\Celebs\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Celebs\Celebs\Interfaces\CelOcuRepositoryInterface;
use Celebs\Celebs\Repositories\Presenter\CelOcuItemTransformer;

/**
 * Pubic API controller class.
 */
class CelOcuPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Celebs\CelOcu\Interfaces\CelOcuRepositoryInterface $cel_ocu
     *
     * @return type
     */
    public function __construct(CelOcuRepositoryInterface $cel_ocu)
    {
        $this->repository = $cel_ocu;
        parent::__construct();
    }

    /**
     * Show cel_ocu's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $cel_ocus = $this->repository
            ->setPresenter('\\Celebs\\Celebs\\Repositories\\Presenter\\CelOcuListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $cel_ocus['code'] = 2000;
        return response()->json($cel_ocus)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show cel_ocu.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $cel_ocu = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($cel_ocu)) {
            $cel_ocu         = $this->itemPresenter($module, new CelOcuItemTransformer);
            $cel_ocu['code'] = 2001;
            return response()->json($cel_ocu)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
