<?php

namespace Celebs\Celebs\Http\Controllers\Api;

use App\Http\Controllers\Api\UserController as BaseController;
use Celebs\Celebs\Http\Requests\CelOcuRequest;
use Celebs\Celebs\Interfaces\CelOcuRepositoryInterface;
use Celebs\Celebs\Models\CelOcu;

/**
 * User API controller class.
 */
class CelOcuUserController extends BaseController
{
    /**
     * Initialize cel_ocu controller.
     *
     * @param type CelOcuRepositoryInterface $cel_ocu
     *
     * @return type
     */
    public function __construct(CelOcuRepositoryInterface $cel_ocu)
    {
        $this->repository = $cel_ocu;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Celebs\Celebs\Repositories\Criteria\CelOcuUserCriteria());
        parent::__construct();
    }

    /**
     * Display a list of cel_ocu.
     *
     * @return json
     */
    public function index(CelOcuRequest $request)
    {
        $cel_ocus  = $this->repository
            ->setPresenter('\\Celebs\\Celebs\\Repositories\\Presenter\\CelOcuListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $cel_ocus['code'] = 2000;
        return response()->json($cel_ocus) 
            ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display cel_ocu.
     *
     * @param Request $request
     * @param Model   CelOcu
     *
     * @return Json
     */
    public function show(CelOcuRequest $request, CelOcu $cel_ocu)
    {

        if ($cel_ocu->exists) {
            $cel_ocu         = $cel_ocu->presenter();
            $cel_ocu['code'] = 2001;
            return response()->json($cel_ocu)
                ->setStatusCode(200, 'SHOW_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }

    /**
     * Show the form for creating a new cel_ocu.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(CelOcuRequest $request, CelOcu $cel_ocu)
    {
        $cel_ocu         = $cel_ocu->presenter();
        $cel_ocu['code'] = 2002;
        return response()->json($cel_ocu)
            ->setStatusCode(200, 'CREATE_SUCCESS');
    }

    /**
     * Create new cel_ocu.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(CelOcuRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $cel_ocu          = $this->repository->create($attributes);
            $cel_ocu          = $cel_ocu->presenter();
            $cel_ocu['code']  = 2004;

            return response()->json($cel_ocu)
                ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message' => $e->getMessage(),
                'code'    => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }

    }

    /**
     * Show cel_ocu for editing.
     *
     * @param Request $request
     * @param Model   $cel_ocu
     *
     * @return json
     */
    public function edit(CelOcuRequest $request, CelOcu $cel_ocu)
    {
        if ($cel_ocu->exists) {
            $cel_ocu         = $cel_ocu->presenter();
            $cel_ocu['code'] = 2003;
            return response()-> json($cel_ocu)
                ->setStatusCode(200, 'EDIT_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }
    }

    /**
     * Update the cel_ocu.
     *
     * @param Request $request
     * @param Model   $cel_ocu
     *
     * @return json
     */
    public function update(CelOcuRequest $request, CelOcu $cel_ocu)
    {
        try {

            $attributes = $request->all();

            $cel_ocu->update($attributes);
            $cel_ocu         = $cel_ocu->presenter();
            $cel_ocu['code'] = 2005;

            return response()->json($cel_ocu)
                ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the cel_ocu.
     *
     * @param Request $request
     * @param Model   $cel_ocu
     *
     * @return json
     */
    public function destroy(CelOcuRequest $request, CelOcu $cel_ocu)
    {

        try {

            $t = $cel_ocu->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('celebs::cel_ocu.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
