<?php

namespace Celebs\Celebs\Http\Controllers\Api;

use App\Http\Controllers\Api\AdminController as BaseController;
use Celebs\Celebs\Http\Requests\OccupationRequest;
use Celebs\Celebs\Interfaces\OccupationRepositoryInterface;
use Celebs\Celebs\Models\Occupation;

/**
 * Admin API controller class.
 */
class OccupationAdminController extends BaseController
{
    /**
     * Initialize occupation controller.
     *
     * @param type OccupationRepositoryInterface $occupation
     *
     * @return type
     */
    public function __construct(OccupationRepositoryInterface $occupation)
    {
        $this->repository = $occupation;
        parent::__construct();
    }

    /**
     * Display a list of occupation.
     *
     * @return json
     */
    public function index(OccupationRequest $request)
    {
        $occupations  = $this->repository
            ->setPresenter('\\Celebs\\Celebs\\Repositories\\Presenter\\OccupationListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $occupations['code'] = 2000;
        return response()->json($occupations) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display occupation.
     *
     * @param Request $request
     * @param Model   Occupation
     *
     * @return Json
     */
    public function show(OccupationRequest $request, Occupation $occupation)
    {
        $occupation         = $occupation->presenter();
        $occupation['code'] = 2001;
        return response()->json($occupation)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new occupation.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(OccupationRequest $request, Occupation $occupation)
    {
        $occupation         = $occupation->presenter();
        $occupation['code'] = 2002;
        return response()->json($occupation)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new occupation.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(OccupationRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $occupation          = $this->repository->create($attributes);
            $occupation          = $occupation->presenter();
            $occupation['code']  = 2004;

            return response()->json($occupation)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }
    }

    /**
     * Show occupation for editing.
     *
     * @param Request $request
     * @param Model   $occupation
     *
     * @return json
     */
    public function edit(OccupationRequest $request, Occupation $occupation)
    {
        $occupation         = $occupation->presenter();
        $occupation['code'] = 2003;
        return response()-> json($occupation)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the occupation.
     *
     * @param Request $request
     * @param Model   $occupation
     *
     * @return json
     */
    public function update(OccupationRequest $request, Occupation $occupation)
    {
        try {

            $attributes = $request->all();

            $occupation->update($attributes);
            $occupation         = $occupation->presenter();
            $occupation['code'] = 2005;

            return response()->json($occupation)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the occupation.
     *
     * @param Request $request
     * @param Model   $occupation
     *
     * @return json
     */
    public function destroy(OccupationRequest $request, Occupation $occupation)
    {
        try {
            $t = $occupation->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('celebs::occupation.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
