<?php

namespace Celebs\Celebs\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Celebs\Celebs\Interfaces\OccupationRepositoryInterface;
use Celebs\Celebs\Repositories\Presenter\OccupationItemTransformer;

/**
 * Pubic API controller class.
 */
class OccupationPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Celebs\Occupation\Interfaces\OccupationRepositoryInterface $occupation
     *
     * @return type
     */
    public function __construct(OccupationRepositoryInterface $occupation)
    {
        $this->repository = $occupation;
        parent::__construct();
    }

    /**
     * Show occupation's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $occupations = $this->repository
            ->setPresenter('\\Celebs\\Celebs\\Repositories\\Presenter\\OccupationListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $occupations['code'] = 2000;
        return response()->json($occupations)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show occupation.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $occupation = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($occupation)) {
            $occupation         = $this->itemPresenter($module, new OccupationItemTransformer);
            $occupation['code'] = 2001;
            return response()->json($occupation)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
