<?php

namespace Celebs\Celebs\Http\Controllers;

use App\Http\Controllers\AdminController as BaseController;
use Form;
use Celebs\Celebs\Http\Requests\CelOcuRequest;
use Celebs\Celebs\Interfaces\CelOcuRepositoryInterface;
use Celebs\Celebs\Models\CelOcu;

/**
 * Admin web controller class.
 */
class CelOcuAdminController extends BaseController
{
    // use CelOcuWorkflow;
    /**
     * Initialize cel_ocu controller.
     *
     * @param type CelOcuRepositoryInterface $cel_ocu
     *
     * @return type
     */
    public function __construct(CelOcuRepositoryInterface $cel_ocu)
    {
        $this->repository = $cel_ocu;
        parent::__construct();
    }

    /**
     * Display a list of cel_ocu.
     *
     * @return Response
     */
    public function index(CelOcuRequest $request)
    {
        if ($request->wantsJson()) {
            return $this->getJson($request);
        }
        $this   ->theme->prependTitle(trans('celebs::cel_ocu.names').' :: ');
        return $this->theme->of('celebs::admin.cel_ocu.index')->render();
    }

    /**
     * Display a list of cel_ocu.
     *
     * @return Response
     */
    public function getJson(CelOcuRequest $request)
    {
        $pageLimit = $request->input('pageLimit');

        $cel_ocus  = $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->setPresenter('\\Celebs\\Celebs\\Repositories\\Presenter\\CelOcuListPresenter')
                ->scopeQuery(function($query){
                    return $query->orderBy('id','DESC');
                })->paginate($pageLimit);
        $cel_ocus['recordsTotal']    = $cel_ocus['meta']['pagination']['total'];
        $cel_ocus['recordsFiltered'] = $cel_ocus['meta']['pagination']['total'];
        $cel_ocus['request']         = $request->all();
        return response()->json($cel_ocus, 200);

    }

    /**
     * Display cel_ocu.
     *
     * @param Request $request
     * @param Model   $cel_ocu
     *
     * @return Response
     */
    public function show(CelOcuRequest $request, CelOcu $cel_ocu)
    {
        if (!$cel_ocu->exists) {
            return response()->view('celebs::admin.cel_ocu.new', compact('cel_ocu'));
        }

        Form::populate($cel_ocu);
        return response()->view('celebs::admin.cel_ocu.show', compact('cel_ocu'));
    }

    /**
     * Show the form for creating a new cel_ocu.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CelOcuRequest $request)
    {

        $cel_ocu = $this->repository->newInstance([]);

        Form::populate($cel_ocu);

        return response()->view('celebs::admin.cel_ocu.create', compact('cel_ocu'));

    }

    /**
     * Create new cel_ocu.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CelOcuRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $cel_ocu          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('celebs::cel_ocu.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/celebs/cel_ocu/'.$cel_ocu->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show cel_ocu for editing.
     *
     * @param Request $request
     * @param Model   $cel_ocu
     *
     * @return Response
     */
    public function edit(CelOcuRequest $request, CelOcu $cel_ocu)
    {
        Form::populate($cel_ocu);
        return  response()->view('celebs::admin.cel_ocu.edit', compact('cel_ocu'));
    }

    /**
     * Update the cel_ocu.
     *
     * @param Request $request
     * @param Model   $cel_ocu
     *
     * @return Response
     */
    public function update(CelOcuRequest $request, CelOcu $cel_ocu)
    {
        try {

            $attributes = $request->all();

            $cel_ocu->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('celebs::cel_ocu.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/celebs/cel_ocu/'.$cel_ocu->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/celebs/cel_ocu/'.$cel_ocu->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the cel_ocu.
     *
     * @param Model   $cel_ocu
     *
     * @return Response
     */
    public function destroy(CelOcuRequest $request, CelOcu $cel_ocu)
    {

        try {

            $t = $cel_ocu->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('celebs::cel_ocu.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/celebs/cel_ocu/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/celebs/cel_ocu/'.$cel_ocu->getRouteKey()),
            ], 400);
        }
    }

}
