<?php

namespace Celebs\Celebs\Http\Controllers;
use Litepie\Celebs\Http\Requests\CelOcuRequest;
use Litepie\Celebs\Models\CelOcu;

trait CelOcuWorkflow {
	
    /**
     * Workflow controller function for cel_ocu.
     *
     * @param Model   $cel_ocu
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CelOcuRequest $request, CelOcu $cel_ocu, $step)
    {

        try {

            $cel_ocu->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('celebs::cel_ocu.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/cel_ocu/cel_ocu/' . $cel_ocu->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/cel_ocu/cel_ocu/' . $cel_ocu->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for cel_ocu.
     *
     * @param Model   $cel_ocu
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(CelOcu $cel_ocu, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $cel_ocu->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('celebs::cel_ocu.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('celebs::admin.cel_ocu.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('celebs::admin.cel_ocu.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('celebs::admin.cel_ocu.message', $data)->render();

        }

    }
}