<?php

namespace Celebs\Celebs\Http\Controllers;
use Litepie\Celebs\Http\Requests\CelebsRequest;
use Litepie\Celebs\Models\Celebs;

trait CelebsWorkflow {
	
    /**
     * Workflow controller function for celebs.
     *
     * @param Model   $celebs
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CelebsRequest $request, Celebs $celebs, $step)
    {

        try {

            $celebs->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('celebs::celebs.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/celebs/celebs/' . $celebs->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/celebs/celebs/' . $celebs->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for celebs.
     *
     * @param Model   $celebs
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Celebs $celebs, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $celebs->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('celebs::celebs.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('celebs::admin.celebs.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('celebs::admin.celebs.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('celebs::admin.celebs.message', $data)->render();

        }

    }
}