<?php

namespace Celebs\Celebs\Http\Controllers;
use Litepie\Celebs\Http\Requests\OccupationRequest;
use Litepie\Celebs\Models\Occupation;

trait OccupationWorkflow {
	
    /**
     * Workflow controller function for occupation.
     *
     * @param Model   $occupation
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(OccupationRequest $request, Occupation $occupation, $step)
    {

        try {

            $occupation->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('celebs::occupation.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/occupation/occupation/' . $occupation->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/occupation/occupation/' . $occupation->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for occupation.
     *
     * @param Model   $occupation
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Occupation $occupation, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $occupation->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('celebs::occupation.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('celebs::admin.occupation.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('celebs::admin.occupation.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('celebs::admin.occupation.message', $data)->render();

        }

    }
}