<?php

namespace Celebs\Celebs\Policies;

use App\User;
use Celebs\Celebs\Models\CelOcu;

class CelOcuPolicy
{

    /**
     * Determine if the given user can view the cel_ocu.
     *
     * @param User $user
     * @param CelOcu $cel_ocu
     *
     * @return bool
     */
    public function view(User $user, CelOcu $cel_ocu)
    {
        if ($user->canDo('celebs.cel_ocu.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $cel_ocu->user_id;
    }

    /**
     * Determine if the given user can create a cel_ocu.
     *
     * @param User $user
     * @param CelOcu $cel_ocu
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('celebs.cel_ocu.create');
    }

    /**
     * Determine if the given user can update the given cel_ocu.
     *
     * @param User $user
     * @param CelOcu $cel_ocu
     *
     * @return bool
     */
    public function update(User $user, CelOcu $cel_ocu)
    {
        if ($user->canDo('celebs.cel_ocu.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $cel_ocu->user_id;
    }

    /**
     * Determine if the given user can delete the given cel_ocu.
     *
     * @param User $user
     * @param CelOcu $cel_ocu
     *
     * @return bool
     */
    public function destroy(User $user, CelOcu $cel_ocu)
    {
        if ($user->canDo('celebs.cel_ocu.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $cel_ocu->user_id;
    }

    /**
     * Determine if the given user can verify the given cel_ocu.
     *
     * @param User $user
     * @param CelOcu $cel_ocu
     *
     * @return bool
     */
    public function verify(User $user, CelOcu $cel_ocu)
    {
        if ($user->canDo('celebs.cel_ocu.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('celebs.cel_ocu.verify') 
        && $user->is('manager')
        && $cel_ocu->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given cel_ocu.
     *
     * @param User $user
     * @param CelOcu $cel_ocu
     *
     * @return bool
     */
    public function approve(User $user, CelOcu $cel_ocu)
    {
        if ($user->canDo('celebs.cel_ocu.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
