<?php

namespace Celebs\Celebs\Policies;

use App\User;
use Celebs\Celebs\Models\Celebs;

class CelebsPolicy
{

    /**
     * Determine if the given user can view the celebs.
     *
     * @param User $user
     * @param Celebs $celebs
     *
     * @return bool
     */
    public function view(User $user, Celebs $celebs)
    {
        if ($user->canDo('celebs.celebs.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $celebs->user_id;
    }

    /**
     * Determine if the given user can create a celebs.
     *
     * @param User $user
     * @param Celebs $celebs
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('celebs.celebs.create');
    }

    /**
     * Determine if the given user can update the given celebs.
     *
     * @param User $user
     * @param Celebs $celebs
     *
     * @return bool
     */
    public function update(User $user, Celebs $celebs)
    {
        if ($user->canDo('celebs.celebs.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $celebs->user_id;
    }

    /**
     * Determine if the given user can delete the given celebs.
     *
     * @param User $user
     * @param Celebs $celebs
     *
     * @return bool
     */
    public function destroy(User $user, Celebs $celebs)
    {
        if ($user->canDo('celebs.celebs.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $celebs->user_id;
    }

    /**
     * Determine if the given user can verify the given celebs.
     *
     * @param User $user
     * @param Celebs $celebs
     *
     * @return bool
     */
    public function verify(User $user, Celebs $celebs)
    {
        if ($user->canDo('celebs.celebs.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('celebs.celebs.verify') 
        && $user->is('manager')
        && $celebs->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given celebs.
     *
     * @param User $user
     * @param Celebs $celebs
     *
     * @return bool
     */
    public function approve(User $user, Celebs $celebs)
    {
        if ($user->canDo('celebs.celebs.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
