<?php

namespace Celebs\Celebs\Policies;

use App\User;
use Celebs\Celebs\Models\Occupation;

class OccupationPolicy
{

    /**
     * Determine if the given user can view the occupation.
     *
     * @param User $user
     * @param Occupation $occupation
     *
     * @return bool
     */
    public function view(User $user, Occupation $occupation)
    {
        if ($user->canDo('celebs.occupation.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $occupation->user_id;
    }

    /**
     * Determine if the given user can create a occupation.
     *
     * @param User $user
     * @param Occupation $occupation
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('celebs.occupation.create');
    }

    /**
     * Determine if the given user can update the given occupation.
     *
     * @param User $user
     * @param Occupation $occupation
     *
     * @return bool
     */
    public function update(User $user, Occupation $occupation)
    {
        if ($user->canDo('celebs.occupation.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $occupation->user_id;
    }

    /**
     * Determine if the given user can delete the given occupation.
     *
     * @param User $user
     * @param Occupation $occupation
     *
     * @return bool
     */
    public function destroy(User $user, Occupation $occupation)
    {
        if ($user->canDo('celebs.occupation.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $occupation->user_id;
    }

    /**
     * Determine if the given user can verify the given occupation.
     *
     * @param User $user
     * @param Occupation $occupation
     *
     * @return bool
     */
    public function verify(User $user, Occupation $occupation)
    {
        if ($user->canDo('celebs.occupation.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('celebs.occupation.verify') 
        && $user->is('manager')
        && $occupation->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given occupation.
     *
     * @param User $user
     * @param Occupation $occupation
     *
     * @return bool
     */
    public function approve(User $user, Occupation $occupation)
    {
        if ($user->canDo('celebs.occupation.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
