<?php

namespace Celebs\Celebs\Providers;

use Illuminate\Support\ServiceProvider;

class CelebsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'celebs');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'celebs');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('celebs', function ($app) {
            return $this->app->make('Celebs\Celebs\Celebs');
        });

// Bind Celebs to repository
        $this->app->bind(
            \Celebs\Celebs\Interfaces\CelebsRepositoryInterface::class,
            \Celebs\Celebs\Repositories\Eloquent\CelebsRepository::class
        );
        // Bind Occupation to repository
        $this->app->bind(
            \Celebs\Celebs\Interfaces\OccupationRepositoryInterface::class,
            \Celebs\Celebs\Repositories\Eloquent\OccupationRepository::class
        );
        // Bind CelOcu to repository
        $this->app->bind(
            \Celebs\Celebs\Interfaces\CelOcuRepositoryInterface::class,
            \Celebs\Celebs\Repositories\Eloquent\CelOcuRepository::class
        );

        $this->app->register(\Celebs\Celebs\Providers\AuthServiceProvider::class);
        $this->app->register(\Celebs\Celebs\Providers\EventServiceProvider::class);
        $this->app->register(\Celebs\Celebs\Providers\RouteServiceProvider::class);
        // $this->app->register(\Celebs\Celebs\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['celebs'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('celebs/celebs.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/celebs')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/celebs')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
