<?php

namespace Celebs\Celebs\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Celebs\Celebs\Models\Celebs;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Celebs\Celebs\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/celebs/celebs/*')) {
            Route::bind('celebs', function ($celebs) {
                $celebsrepo = $this->app->make('\Celebs\Celebs\Interfaces\CelebsRepositoryInterface');
                return $celebsrepo->findorNew($celebs);
            });
        }
if (Request::is('*/celebs/occupation/*')) {
            Route::bind('occupation', function ($occupation) {
                $occupationrepo = $this->app->make('\Celebs\Celebs\Interfaces\OccupationRepositoryInterface');
                return $occupationrepo->findorNew($occupation);
            });
        }
if (Request::is('*/celebs/cel_ocu/*')) {
            Route::bind('cel_ocu', function ($cel_ocu) {
                $cel_ocurepo = $this->app->make('\Celebs\Celebs\Interfaces\CelOcuRepositoryInterface');
                return $cel_ocurepo->findorNew($cel_ocu);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        // $this->mapApiRoutes();

        //
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        Route::group([
            'middleware' => 'web',
            'namespace' => $this->namespace,
            'prefix' => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace' => $this->namespace . '\Api',
            'prefix' => trans_setlocale() . '/api',
        ], function ($router) {
            require (__DIR__ . '/../../../../routes/api.php');
        });
    }
}
