<?php

namespace Celebs\Celebs\Workflow;

use Celebs\Celebs\Models\CelOcu;
use Validator;

class CelOcuValidator
{

    /**
     * Determine if the given cel_ocu is valid for complete status.
     *
     * @param CelOcu $cel_ocu
     *
     * @return bool / Validator
     */
    public function complete(CelOcu $cel_ocu)
    {
        return Validator::make($cel_ocu->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given cel_ocu is valid for verify status.
     *
     * @param CelOcu $cel_ocu
     *
     * @return bool / Validator
     */
    public function verify(CelOcu $cel_ocu)
    {
        return Validator::make($cel_ocu->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given cel_ocu is valid for approve status.
     *
     * @param CelOcu $cel_ocu
     *
     * @return bool / Validator
     */
    public function approve(CelOcu $cel_ocu)
    {
        return Validator::make($cel_ocu->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given cel_ocu is valid for publish status.
     *
     * @param CelOcu $cel_ocu
     *
     * @return bool / Validator
     */
    public function publish(CelOcu $cel_ocu)
    {
        return Validator::make($cel_ocu->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given cel_ocu is valid for archive status.
     *
     * @param CelOcu $cel_ocu
     *
     * @return bool / Validator
     */
    public function archive(CelOcu $cel_ocu)
    {
        return Validator::make($cel_ocu->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given cel_ocu is valid for unpublish status.
     *
     * @param CelOcu $cel_ocu
     *
     * @return bool / Validator
     */
    public function unpublish(CelOcu $cel_ocu)
    {
        return Validator::make($cel_ocu->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
