<?php

namespace Celebs\Celebs\Workflow;

use Celebs\Celebs\Models\Celebs;
use Validator;

class CelebsValidator
{

    /**
     * Determine if the given celebs is valid for complete status.
     *
     * @param Celebs $celebs
     *
     * @return bool / Validator
     */
    public function complete(Celebs $celebs)
    {
        return Validator::make($celebs->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given celebs is valid for verify status.
     *
     * @param Celebs $celebs
     *
     * @return bool / Validator
     */
    public function verify(Celebs $celebs)
    {
        return Validator::make($celebs->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given celebs is valid for approve status.
     *
     * @param Celebs $celebs
     *
     * @return bool / Validator
     */
    public function approve(Celebs $celebs)
    {
        return Validator::make($celebs->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given celebs is valid for publish status.
     *
     * @param Celebs $celebs
     *
     * @return bool / Validator
     */
    public function publish(Celebs $celebs)
    {
        return Validator::make($celebs->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given celebs is valid for archive status.
     *
     * @param Celebs $celebs
     *
     * @return bool / Validator
     */
    public function archive(Celebs $celebs)
    {
        return Validator::make($celebs->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given celebs is valid for unpublish status.
     *
     * @param Celebs $celebs
     *
     * @return bool / Validator
     */
    public function unpublish(Celebs $celebs)
    {
        return Validator::make($celebs->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
