<?php

namespace Celebs\Celebs\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Celebs\Celebs\Models\Occupation;

class OccupationAction
{
    /**
     * Perform the complete action.
     *
     * @param Occupation $occupation
     *
     * @return Occupation
     */
    public function complete(Occupation $occupation)
    {
        try {
            $occupation->status = 'complete';
            return $occupation->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Occupation $occupation
     *
     * @return Occupation
     */public function verify(Occupation $occupation)
    {
        try {
            $occupation->status = 'verify';
            return $occupation->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Occupation $occupation
     *
     * @return Occupation
     */public function approve(Occupation $occupation)
    {
        try {
            $occupation->status = 'approve';
            return $occupation->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Occupation $occupation
     *
     * @return Occupation
     */public function publish(Occupation $occupation)
    {
        try {
            $occupation->status = 'publish';
            return $occupation->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Occupation $occupation
     *
     * @return Occupation
     */
    public function archive(Occupation $occupation)
    {
        try {
            $occupation->status = 'archive';
            return $occupation->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Occupation $occupation
     *
     * @return Occupation
     */
    public function unpublish(Occupation $occupation)
    {
        try {
            $occupation->status = 'unpublish';
            return $occupation->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
