<?php

namespace Celebs\Celebs\Workflow;

use Celebs\Celebs\Models\Occupation;
use Validator;

class OccupationValidator
{

    /**
     * Determine if the given occupation is valid for complete status.
     *
     * @param Occupation $occupation
     *
     * @return bool / Validator
     */
    public function complete(Occupation $occupation)
    {
        return Validator::make($occupation->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given occupation is valid for verify status.
     *
     * @param Occupation $occupation
     *
     * @return bool / Validator
     */
    public function verify(Occupation $occupation)
    {
        return Validator::make($occupation->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given occupation is valid for approve status.
     *
     * @param Occupation $occupation
     *
     * @return bool / Validator
     */
    public function approve(Occupation $occupation)
    {
        return Validator::make($occupation->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given occupation is valid for publish status.
     *
     * @param Occupation $occupation
     *
     * @return bool / Validator
     */
    public function publish(Occupation $occupation)
    {
        return Validator::make($occupation->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given occupation is valid for archive status.
     *
     * @param Occupation $occupation
     *
     * @return bool / Validator
     */
    public function archive(Occupation $occupation)
    {
        return Validator::make($occupation->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given occupation is valid for unpublish status.
     *
     * @param Occupation $occupation
     *
     * @return bool / Validator
     */
    public function unpublish(Occupation $occupation)
    {
        return Validator::make($occupation->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
